@@ -3,7 +3,6 @@ from mindsdb_sql.parser.parser import SQLParser
 from mindsdb_sql.parser.ast import *
 from mindsdb_sql.parser.dialects.mysql.lexer import MySQLLexer
 from mindsdb_sql.parser.dialects.mysql.variable import Variable
-from mindsdb_sql.parser.dialects.mysql.show_index import ShowIndex
 from mindsdb_sql.exceptions import ParsingException
 from mindsdb_sql.parser.utils import ensure_select_keyword_order, JoinType
 
@@ -18,7 +17,7 @@ class MySQLParser(SQLParser):
         ('left', PLUS, MINUS, OR),
         ('left', STAR, DIVIDE, AND),
         ('right', UMINUS, UNOT),  # Unary minus operator, unary not
-        ('nonassoc', LESS, LEQ, GREATER, GEQ, EQUALS, NEQUALS, IN, BETWEEN, IS, LIKE),
+        ('nonassoc', LESS, LEQ, GREATER, GEQ, EQUALS, NEQUALS, IN, BETWEEN, IS, IS_NOT, LIKE),
     )
 
     # Top-level statements
@@ -47,10 +46,10 @@ class MySQLParser(SQLParser):
         return Explain(target=p.identifier)
 
     # Alter table
-    @_('ALTER TABLE identifier ID ID')
+    @_('ALTER TABLE identifier id id')
     def alter_table(self, p):
         return AlterTable(target=p.identifier,
-                          arg=' '.join([p.ID0, p.ID1]))
+                          arg=' '.join([p.id0, p.id1]))
 
     # DROP VEW
     @_('DROP VIEW identifier')
@@ -76,8 +75,10 @@ class MySQLParser(SQLParser):
 
     # Transactions
 
-    @_('START TRANSACTION')
+    @_('START TRANSACTION',
+       'BEGIN')
     def start_transaction(self, p):
+        # https://dev.mysql.com/doc/refman/8.0/en/commit.html
         return StartTransaction()
 
     @_('COMMIT')
@@ -90,34 +91,11 @@ class MySQLParser(SQLParser):
 
     # Set
 
-    @_('SET expr_list')
-    @_('SET set_modifier expr_list')
+    @_('SET id identifier')
     def set(self, p):
-        if len(p.expr_list) == 1:
-            arg = p.expr_list[0]
-        else:
-            arg = Tuple(items=p.expr_list)
-
-        if hasattr(p, 'set_modifier'):
-            category = p.set_modifier
-        else:
-            category = None
-
-        return Set(category=category, arg=arg)
-
-    @_('SET ID identifier')
-    def set(self, p):
-        if not p.ID.lower() == 'names':
-            raise ParsingException(f'Expected "SET names", got "SET {p.ID}"')
-        return Set(category=p.ID.lower(), arg=p.identifier)
-
-    @_('GLOBAL',
-       'PERSIST',
-       'PERSIST_ONLY',
-       'SESSION',
-       )
-    def set_modifier(self, p):
-        return p[0]
+        if not p.id.lower() == 'names':
+            raise ParsingException(f'Expected "SET names", got "SET {p.id}"')
+        return Set(category=p.id.lower(), arg=p.identifier)
 
     # set charset
     @_('SET charset constant')
@@ -137,9 +115,11 @@ class MySQLParser(SQLParser):
 
     # set transaction
     @_('SET transact_scope TRANSACTION transact_property_list')
+    @_('SET TRANSACTION transact_property_list')
     def set(self, p):
         isolation_level = None
         access_mode = None
+        transact_scope = getattr(p, 'transact_scope', None)
         for prop in p.transact_property_list:
             if prop['type'] == 'iso_level':
                 isolation_level = prop['value']
@@ -149,12 +129,11 @@ class MySQLParser(SQLParser):
         return SetTransaction(
             isolation_level=isolation_level,
             access_mode=access_mode,
-            scope=p.transact_scope,
+            scope=transact_scope,
         )
 
     @_('GLOBAL',
-       'SESSION',
-       'empty')
+       'SESSION')
     def transact_scope(self, p):
         return p[0]
 
@@ -186,60 +165,158 @@ class MySQLParser(SQLParser):
     def transact_access_mode(self, p):
         return ' '.join([x for x in p])
 
+    @_('SET expr_list')
+    @_('SET set_modifier expr_list')
+    def set(self, p):
+        if len(p.expr_list) == 1:
+            arg = p.expr_list[0]
+        else:
+            arg = Tuple(items=p.expr_list)
+
+        if hasattr(p, 'set_modifier'):
+            category = p.set_modifier
+        else:
+            category = None
+
+        return Set(category=category, arg=arg)
+
+    @_('GLOBAL',
+       'PERSIST',
+       'PERSIST_ONLY',
+       'SESSION',
+       )
+    def set_modifier(self, p):
+        return p[0]
 
     # Show
-    @_('SHOW show_category show_condition_or_nothing')
+    @_('show WHERE expr')
     def show(self, p):
-        condition = p.show_condition_or_nothing['condition'] if p.show_condition_or_nothing else None
-        expression = p.show_condition_or_nothing['expression'] if p.show_condition_or_nothing else None
-        return Show(category=p.show_category,
-                    condition=condition,
-                    expression=expression)
+        command = p.show
+        command.where = p.expr
+        return command
 
-    @_('SHOW INDEX FROM identifier FROM identifier')
+    @_('show LIKE string')
     def show(self, p):
-        return ShowIndex(table=p.identifier0,
-                         db=p.identifier1)
+        command = p.show
+        command.like = p.string
+        return command
 
-    @_('SHOW INDEX FROM identifier')
+    @_('show FROM identifier')
     def show(self, p):
-        return ShowIndex(table=p.identifier)
+        command = p.show
+        value0 = command.from_table
+        value1 = p.identifier
+        if value0 is not None:
+            value1.parts = value1.parts + value0.parts
 
-    @_('show_condition_token expr',
-       'empty')
-    def show_condition_or_nothing(self, p):
-        if not p[0]:
-            return None
-        return dict(condition=p[0], expression=p[1])
+        command.from_table = value1
+        return command
 
-    @_('WHERE',
-       'FROM',
-       'LIKE')
-    def show_condition_token(self, p):
-        return p[0]
+    @_('show IN identifier')
+    def show(self, p):
+        command = p.show
+        value0 = command.in_table
+        value1 = p.identifier
+        if value0 is not None:
+            value1.parts = value1.parts + value0.parts
+
+        command.in_table = value1
+        return command
+
+    @_('SHOW show_category',
+       'SHOW show_modifier_list show_category')
+    def show(self, p):
+        modes = getattr(p, 'show_modifier_list', None)
+        return Show(
+            category=p.show_category,
+            modes=modes
+        )
 
     @_('SCHEMAS',
        'DATABASES',
        'TABLES',
-       'FULL TABLES',
-       'VARIABLES',
+       'OPEN TABLES',
+       'TRIGGERS',
+       'COLUMNS',
+       'FIELDS',
        'PLUGINS',
+       'VARIABLES',
+       'INDEXES',
+       'KEYS',
        'SESSION VARIABLES',
-       'SESSION STATUS',
        'GLOBAL VARIABLES',
+       'GLOBAL STATUS',
+       'SESSION STATUS',
        'PROCEDURE STATUS',
        'FUNCTION STATUS',
+       'TABLE STATUS',
+       'MASTER STATUS',
+       'STATUS',
+       'STORAGE ENGINES',
+       'PROCESSLIST',
+       'INDEX',
        'CREATE TABLE',
        'WARNINGS',
        'ENGINES',
        'CHARSET',
        'CHARACTER SET',
        'COLLATION',
-       'TABLE STATUS',
-       'STATUS')
+       'BINARY LOGS',
+       'MASTER LOGS',
+       'PRIVILEGES',
+       'PROFILES',
+       'REPLICAS',
+       'SLAVE HOSTS',
+       )
     def show_category(self, p):
         return ' '.join([x for x in p])
 
+    # custom show commands
+    @_('SHOW ENGINE identifier STATUS',
+       'SHOW ENGINE identifier MUTEX')
+    def show(self, p):
+        return Show(
+            category=p[1],
+            name=p.identifier.to_string(),
+            modes=[p[3]]
+        )
+
+    @_('SHOW FUNCTION CODE identifier',
+       'SHOW PROCEDURE CODE identifier')
+    def show(self, p):
+        category = p[1] + ' ' + p[2]
+        return Show(
+            category=category,
+            name=p.identifier.to_string()
+        )
+
+    @_('SHOW REPLICA STATUS FOR CHANNEL identifier',
+       'SHOW SLAVE STATUS FOR CHANNEL identifier',
+       'SHOW REPLICA STATUS',
+       'SHOW SLAVE STATUS',)
+    def show(self, p):
+        name = getattr(p, 'identifier', None)
+        if name is not None:
+            name = name.to_string()
+        return Show(
+            category='REPLICA STATUS', # slave = replica
+            name=name
+        )
+
+    @_('show_modifier',
+       'show_modifier_list show_modifier')
+    def show_modifier_list(self, p):
+        if hasattr(p, 'empty'):
+            return None
+        params = getattr(p, 'show_modifier_list', [])
+        params.append(p.show_modifier)
+        return params
+
+    @_('EXTENDED',
+       'FULL')
+    def show_modifier(self, p):
+        return p[0]
+
     # DELETE
     @_('DELETE FROM from_table WHERE expr')
     @_('DELETE FROM from_table')
@@ -349,15 +426,6 @@ class MySQLParser(SQLParser):
         select.offset = p.constant
         return select
 
-    @_('select LIMIT constant')
-    def select(self, p):
-        select = p.select
-        ensure_select_keyword_order(select, 'LIMIT')
-        if not isinstance(p.constant.value, int):
-            raise ParsingException(f'LIMIT must be an integer value, got: {p.constant.value}')
-        select.limit = p.constant
-        return select
-
     @_('select LIMIT constant COMMA constant')
     def select(self, p):
         select = p.select
@@ -368,6 +436,15 @@ class MySQLParser(SQLParser):
         select.limit = p.constant1
         return select
 
+    @_('select LIMIT constant')
+    def select(self, p):
+        select = p.select
+        ensure_select_keyword_order(select, 'LIMIT')
+        if not isinstance(p.constant.value, int):
+            raise ParsingException(f'LIMIT must be an integer value, got: {p.constant.value}')
+        select.limit = p.constant
+        return select
+
     @_('select ORDER_BY ordering_terms')
     def select(self, p):
         select = p.select
@@ -607,16 +684,16 @@ class MySQLParser(SQLParser):
     def function(self, p):
         return Function(op=p.DATABASE, args=[])
 
-    @_('ID LPAREN DISTINCT expr_list RPAREN')
+    @_('id LPAREN DISTINCT expr_list RPAREN')
     def function(self, p):
-        return Function(op=p.ID, distinct=True, args=p.expr_list)
+        return Function(op=p.id, distinct=True, args=p.expr_list)
 
-    @_('ID LPAREN expr_list_or_nothing RPAREN')
+    @_('id LPAREN expr_list_or_nothing RPAREN')
     def function(self, p):
         args = p.expr_list_or_nothing
         if not args:
             args = []
-        return Function(op=p.ID, args=args)
+        return Function(op=p.id, args=args)
 
     # arguments are optional in functions, so that things like `select database()` are possible
     @_('expr BETWEEN expr AND expr')
@@ -631,14 +708,14 @@ class MySQLParser(SQLParser):
     def expr_list_or_nothing(self, p):
         pass
 
-    @_('CAST LPAREN expr AS ID RPAREN')
+    @_('CAST LPAREN expr AS id RPAREN')
     def expr(self, p):
-        return TypeCast(arg=p.expr, type_name=str(p.ID))
+        return TypeCast(arg=p.expr, type_name=str(p.id))
 
-    @_('CONVERT LPAREN expr COMMA ID RPAREN')
-    @_('CONVERT LPAREN expr USING ID RPAREN')
+    @_('CONVERT LPAREN expr COMMA id RPAREN')
+    @_('CONVERT LPAREN expr USING id RPAREN')
     def expr(self, p):
-        return TypeCast(arg=p.expr, type_name=str(p.ID))
+        return TypeCast(arg=p.expr, type_name=str(p.id))
 
     @_('enumeration')
     def expr_list(self, p):
@@ -657,8 +734,7 @@ class MySQLParser(SQLParser):
     def star(self, p):
         return Star()
 
-    @_('expr IS NOT expr',
-       'expr NOT IN expr')
+    @_('expr NOT IN expr')
     def expr(self, p):
         op = p[1] + ' ' + p[2]
         return BinaryOperation(op=op, args=(p.expr0, p.expr1))
@@ -676,6 +752,7 @@ class MySQLParser(SQLParser):
        'expr LESS expr',
        'expr AND expr',
        'expr OR expr',
+       'expr IS_NOT expr',
        'expr NOT expr',
        'expr IS expr',
        'expr LIKE expr',
@@ -724,16 +801,15 @@ class MySQLParser(SQLParser):
     def constant(self, p):
         return Constant(value=False)
 
-    @_('INTEGER')
+    @_('integer')
     def constant(self, p):
-        return Constant(value=int(p.INTEGER))
+        return Constant(value=int(p.integer))
 
-    @_('FLOAT')
+    @_('float')
     def constant(self, p):
-        return Constant(value=float(p.FLOAT))
+        return Constant(value=float(p.float))
 
-    @_('QUOTE_STRING')
-    @_('DQUOTE_STRING')
+    @_('string')
     def constant(self, p):
         return Constant(value=str(p[0]))
 
@@ -742,20 +818,95 @@ class MySQLParser(SQLParser):
         p.identifier0.parts += p.identifier1.parts
         return p.identifier0
 
-    @_('ID',
-       'CHARSET',
-       'TABLES',
-       'STATUS',
-       'VIEW',
-       'DQUOTE_STRING')
+    @_('id',
+       'dquote_string')
     def identifier(self, p):
         value = p[0]
         return Identifier.from_path_str(value)
 
+    @_('quote_string',
+       'dquote_string')
+    def string(self, p):
+        return p[0]
+
     @_('PARAMETER')
     def parameter(self, p):
         return Parameter(value=p.PARAMETER)
 
+    # convert to types
+
+    @_('ID',
+       'BEGIN',
+       'CAST',
+       'CHANNEL',
+       'CHARSET',
+       'CODE',
+       'COLLATION',
+       'COLUMNS',
+       'COMMIT',
+       'COMMITTED',
+       'CONCAT',
+       'ENGINE',
+       'ENGINES',
+       'EXTENDED',
+       'FIELDS',
+       # 'FULL', # fixme: is parsed as alias
+       'GLOBAL',
+       'HOSTS',
+       'INDEXES',
+       'ISOLATION',
+       'KEYS',
+       'LEVEL',
+       'LOGS',
+       'MASTER',
+       'MUTEX',
+       'OFFSET',
+       'ONLY',
+       'OPEN',
+       'PARAMETER',
+       'PERSIST',
+       'PLUGINS',
+       'PRIVILEGES',
+       'PROCESSLIST',
+       'PROFILES',
+       'REPEATABLE',
+       'REPLICA',
+       'REPLICAS',
+       'ROLLBACK',
+       'SERIALIZABLE',
+       'SESSION',
+       'SLAVE',
+       'START',
+       'STATUS',
+       'STORAGE',
+       'TABLES',
+       'TRANSACTION',
+       'TRIGGERS',
+       'UNCOMMITTED',
+       'VARIABLES',
+       'VIEW',
+       'WARNINGS',
+    )
+    def id(self, p):
+        return p[0]
+
+    @_('FLOAT')
+    def float(self, p):
+        return float(p[0])
+
+    @_('INTEGER')
+    def integer(self, p):
+        return int(p[0])
+
+    @_('QUOTE_STRING')
+    def quote_string(self, p):
+        return p[0].strip('\'')
+
+    @_('DQUOTE_STRING')
+    def dquote_string(self, p):
+        return p[0].strip('\"')
+
+
     @_('')
     def empty(self, p):
         pass
